@@ -74,10 +74,14 @@ DS <- function(Betah, Sigmah, kappa0, sigma20, m, K, niter = 1000, burnin = 500,
       ts <- sample(1:nchains, 2)
       for (k in 1:K) {
         AA <- list(RES1[[ts[1]]]$mcmcchain$Beta[[k]], RES1[[ts[2]]]$mcmcchain$Beta[[k]]) # Study k
+        # Combine chains along the third dimension
+        draws <- abind::abind(AA, along = 3)
+        # Compute R-hat
+        rhat_val <- posterior::rhat(draws)
         Summary$Beta[[k]] <- data.frame(
           snpnames, apply(RES1[[1]]$mcmcchain$Beta[[k]], 2, mean), apply(RES1[[1]]$mcmcchain$Beta[[k]], 2, sd),
           t(apply(RES1[[1]]$mcmcchain$Beta[[k]], 2, function(x) quantile(x, c(.025, 0.5, .975)))),
-          wiqid::simpleRhat(postpack::post_convert(AA))
+          rhat_val
         )
         colnames(Summary$Beta[[k]]) <- cbind("Name of SNP", "Mean", "SD", "val2.5pc", "Median", "val97.5pc", "BGR")
       }
@@ -97,10 +101,14 @@ DS <- function(Betah, Sigmah, kappa0, sigma20, m, K, niter = 1000, burnin = 500,
       ts <- sample(1:nchains, 2)
       for (k in 1:K) {
         AA <- list(matrix(RES1[[ts[1]]]$mcmcchain$Beta[[k]]), matrix(RES1[[ts[2]]]$mcmcchain$Beta[[k]])) # Study k
+        # Combine chains along the third dimension
+        draws <- abind::abind(AA, along = 3)
+        # Compute R-hat
+        rhat_val <- posterior::rhat(draws)
         Summary$Beta[[k]] <- data.frame(
           snpnames, mean(RES1[[1]]$mcmcchain$Beta[[k]]), sd(RES1[[1]]$mcmcchain$Beta[[k]]),
           t(quantile(RES1[[1]]$mcmcchain$Beta[[k]], c(.025, 0.5, .975))),
-          wiqid::simpleRhat(postpack::post_convert(AA))
+          rhat_val
         )
         colnames(Summary$Beta[[k]]) <- cbind("Name of SNP", "Mean", "SD", "val2.5pc", "Median", "val97.5pc", "BGR")
       }
