@@ -110,11 +110,14 @@ HS <- function(Betah, Sigmah, kappa0 = kappa0, kappastar0 = kappastar0, sigma20
     Summary <- list()
     for (k in 1:K) {
       AA <- list(RES1[[ts[1]]]$mcmcchain$Beta[[k]], RES1[[ts[2]]]$mcmcchain$Beta[[k]]) # Study k
-
+      # Combine chains along the third dimension
+      draws <- abind::abind(AA, along = 3)
+      # Compute R-hat
+      rhat_val <- posterior::rhat(draws)
       Summary$Beta[[k]] <- data.frame(
         snpnames, apply(RES1[[1]]$mcmcchain$Beta[[k]], 2, mean), apply(RES1[[1]]$mcmcchain$Beta[[k]], 2, sd),
         t(apply(RES1[[1]]$mcmcchain$Beta[[k]], 2, function(x) quantile(x, c(.025, 0.5, .975)))),
-        wiqid::simpleRhat(postpack::post_convert(AA))
+        rhat_val
       )
       colnames(Summary$Beta[[k]]) <- cbind("Name of SNP", "Mean", "SD", "val2.5pc", "Median", "val97.5pc", "BGR")
     }
